@@ -5,40 +5,10 @@ use warnings;
 use Config;
 use File::Glob qw( bsd_glob );
 use ExtUtils::MakeMaker ();
-use IPC::Cmd qw( can_run );
+use IPC::Cmd ();
 use lib 'inc';
 use My::ShareConfig;
 
-sub _pkg_config_exe
-{
-  foreach my $cmd ($ENV{PKG_CONFIG}, qw( pkgconf pkg-config ))
-  {
-    next unless defined $cmd;
-    return $cmd if can_run($cmd);
-  }
-  return;
-}
-
-our $VERBOSE = !!$ENV{V};
-
-sub _pkg_config
-{
-  my(@args) = @_;
-  my $cmd = _pkg_config_exe;
-  if(defined $cmd)
-  {
-    my @cmd = ($cmd, @args);
-    print "+@cmd\n" if $VERBOSE;
-    system @cmd;
-    return $? == 0;
-  }
-  else
-  {
-    print "no pkg-config.\n";
-    return;
-  }
-}
-
 sub myWriteMakefile
 {
   my %args = @_;
@@ -58,9 +28,22 @@ sub myWriteMakefile
   }
   else
   {
-    if(_pkg_config('--exists', 'libffi'))
+    require Alien::FFI::pkgconfig    if $^O ne 'MSWin32';
+    require Alien::FFI::PkgConfigPP  if $^O eq 'MSWin32';
+
+    my $alien_install_type_unset = !defined $ENV{ALIEN_INSTALL_TYPE};
+
+    if($alien_install_type_unset && $^O eq 'MSWin32' && Alien::FFI::PkgConfigPP->exists)
     {
-      print "using system libffi via @{[ _pkg_config_exe ]}\n";
+      print "using system libffia via PkgConfigPP\n";
+      $share_config->set(alien => { class => 'Alien::FFI::PkgConfigPP', mode => 'system' });
+      require Alien::Base::Wrapper;
+      Alien::Base::Wrapper->import( 'Alien::FFI::PkgConfigPP', 'Alien::psapi', '!export' );
+      %alien = Alien::Base::Wrapper->mm_args;
+    }
+    elsif($alien_install_type_unset && $^O ne 'MSWin32' && Alien::FFI::pkgconfig->exists)
+    {
+      print "using system libffi via @{[ Alien::FFI::pkgconfig->pkg_config_exe ]}\n";
       $share_config->set(alien => { class => 'Alien::FFI::pkgconfig', mode => 'system' });
       require Alien::Base::Wrapper;
       Alien::Base::Wrapper->import( 'Alien::FFI::pkgconfig', 'Alien::psapi', '!export' );
@@ -217,7 +200,7 @@ sub postamble {
 
   foreach my $key (qw( cc inc ccflags cccdlflags optimize ld ldflags lddlflags ))
   {
-    $postamble .= 
+    $postamble .=
       sprintf "\t$noecho\$(FULLPERL) inc/mm-config-set.pl eumm.%-20s \$(%s)\n", $key, uc $key;
   }
 
